`xotl.tools.future.threading`:mod: - Higher-level threading interface
=====================================================================

.. module:: xotl.tools.future.threading

.. autofunction:: async_call

.. autofunction:: sync_call
